@@ -149,14 +149,24 @@ class FormatDecisionState(object):
     if format_token.Subtype.DICT_SET_GENERATOR in current.subtypes:
       return True
 
-    if (previous.value not in {'(', '=', '*', '**'} and
-        current.value not in '=,)' and
+    if (style.Get('SPLIT_BEFORE_NAMED_ASSIGNS') and
         format_token.Subtype.DEFAULT_OR_NAMED_ASSIGN_ARG_LIST in
         current.subtypes):
-      return style.Get('SPLIT_BEFORE_NAMED_ASSIGNS')
+      if (previous.value not in {'(', '=', '*', '**'} and
+          current.value not in '=,)'): 
+        opening = _GetOpeningParen(current)
+        if opening:
+          arglist_length = (
+              opening.matching_bracket.total_length - opening.total_length +
+              self.column)
+          return arglist_length > column_limit
 
     if previous.value in '{[' and current.lineno != previous.lineno:
-      self.stack[-1].split_before_closing_bracket = True
+      return True
+
+    if (previous.value == ':' and _IsDictionaryValue(current) and
+        current.lineno != previous.lineno):
+      # Retain the split between the dictionary key and value.
       return True
 
     if (format_token.Subtype.COMP_FOR in current.subtypes and
@@ -402,7 +412,7 @@ class FormatDecisionState(object):
     penalty = 0
     if self.column > style.Get('COLUMN_LIMIT'):
       excess_characters = self.column - style.Get('COLUMN_LIMIT')
-      penalty = style.Get('SPLIT_PENALTY_EXCESS_CHARACTER') * excess_characters
+      penalty += style.Get('SPLIT_PENALTY_EXCESS_CHARACTER') * excess_characters
 
     if is_multiline_string:
       # If this is a multiline string, the column is actually the
@@ -438,6 +448,15 @@ def _GetLengthOfSubtype(token, subtype):
   return current.total_length - token.total_length + 1
 
 
+def _GetOpeningParen(current):
+  previous = current
+  while previous is not None and previous.matching_bracket is None:
+    previous = previous.previous_token
+    if previous.ClosesScope():
+      previous = previous.matching_bracket.previous_token
+  return previous
+
+
 class _ParenState(object):
   """Maintains the state of the bracket enclosures.
 
