@@ -23,6 +23,7 @@ from yapf.yapflib import style
 # TODO(morbo): Document the annotations in a centralized place. E.g., the
 # README file.
 UNBREAKABLE = 1000 * 1000
+DOTTED_NAME = 2500
 STRONGLY_CONNECTED = 2000
 CONTIGUOUS_LIST = 500
 
@@ -90,7 +91,10 @@ class _TreePenaltyAssigner(pytree_visitor.PyTreeVisitor):
   def Visit_lambdef(self, node):  # pylint: disable=invalid-name
     # lambdef ::= 'lambda' [varargslist] ':' test
     # Loop over the lambda up to and including the colon.
-    self._SetUnbreakableOnChildren(node)
+    if style.Get('ALLOW_MULTILINE_LAMBDAS'):
+      self._SetStronglyConnected(node)
+    else:
+      self._SetUnbreakableOnChildren(node)
 
   def Visit_parameters(self, node):  # pylint: disable=invalid-name
     # parameters ::= '(' [typedargslist] ')'
@@ -120,20 +124,21 @@ class _TreePenaltyAssigner(pytree_visitor.PyTreeVisitor):
     # dictsetmaker ::= ( (test ':' test
     #                      (comp_for | (',' test ':' test)* [','])) |
     #                    (test (comp_for | (',' test)* [','])) )
-    prev_child = None
     for child in node.children:
       self.Visit(child)
       if pytree_utils.NodeName(child) == 'COLON':
         # This is a key to a dictionary. We don't want to split the key if at
         # all possible.
-        self._SetStronglyConnected(prev_child, child)
-      prev_child = child
+        self._SetStronglyConnected(child)
 
   def Visit_trailer(self, node):  # pylint: disable=invalid-name
     # trailer ::= '(' [arglist] ')' | '[' subscriptlist ']' | '.' NAME
     self.DefaultNodeVisit(node)
     if node.children[0].value == '.':
       self._SetUnbreakableOnChildren(node)
+      pytree_utils.SetNodeAnnotation(
+          node.children[1], pytree_utils.Annotation.SPLIT_PENALTY,
+          DOTTED_NAME)
     elif len(node.children) == 2:
       # Don't split an empty argument list if at all possible.
       self._SetStronglyConnected(node.children[1])
