@@ -158,7 +158,7 @@ def CreatePEP8Style():
       JOIN_MULTIPLE_LINES=True,
       SPACE_BETWEEN_ENDING_COMMA_AND_CLOSING_BRACKET=True,
       SPACES_BEFORE_COMMENT=2,
-      SPLIT_BEFORE_BITWISE_OPERATOR=True,
+      SPLIT_BEFORE_BITWISE_OPERATOR=False,
       SPLIT_BEFORE_LOGICAL_OPERATOR=False,
       SPLIT_BEFORE_NAMED_ASSIGNS=True,
       SPLIT_PENALTY_AFTER_UNARY_OPERATOR=10000,
@@ -188,6 +188,7 @@ def CreateChromiumStyle():
   style['INDENT_DICTIONARY_VALUE'] = True
   style['INDENT_WIDTH'] = 2
   style['JOIN_MULTIPLE_LINES'] = False
+  style['SPLIT_BEFORE_BITWISE_OPERATOR'] = True
   style['SPLIT_PENALTY_FOR_ADDED_LINE_SPLIT'] = 0
   return style
 
